@@ -7,4 +7,6 @@ import os
 UBUNTU_THEME = "/usr/share/openstack-dashboard-ubuntu-theme/static/themes/ubuntu"
 
 if os.path.exists(UBUNTU_THEME):
-    CUSTOM_THEME_PATH = UBUNTU_THEME
+    AVAILABLE_THEMES = [
+        ('ubuntu', 'Ubuntu', UBUNTU_THEME),
+    ]
